Crate f256_pow10_div_pow2_lut

Crate f256_pow10_div_pow2_lut 

Lookup table for converting a f256 value with exponent < 0 to a fixed precision decimal string representation.

Constants

CHUNK_BASE
Base value used to separate chunks by mod operator.
CHUNK_CUTOFF
Number of chunks cut from the head of the lookup table.
CHUNK_SIZE
Number of decimal digits per chunk.
COMPRESSION_RATE
Factor used to compress the number of entries in the lookup table.
SHIFT
Number of bits used to left-shift the values in the lookup table.

Functions

get_pow10_div_pow2_params
lookup_pow10_div_pow2