Lookup table for converting a f256 value with exponent < 0 to a fixed
precision decimal string representation.
Constants
- CHUNK_
BASE - Base value used to separate chunks by mod operator.
- CHUNK_
CUTOFF - Number of chunks cut from the head of the lookup table.
- CHUNK_
SIZE - Number of decimal digits per chunk.
- COMPRESSION_
RATE - Factor used to compress the number of entries in the lookup table.
- SHIFT
- Number of bits used to left-shift the values in the lookup table.